==> spip_4.0.4.orig.tar.xz: plugins-dist/porte_plume/lang/barreoutils_fr_fem.php <==
<?php
// This is a SPIP language file  --  Ceci est un fichier langue de SPIP
// extrait automatiquement de https://trad.spip.net/tradlang_module/barreoutils?lang_cible=fr_fem
// ** ne pas modifier le fichier **

if (!defined('_ECRIRE_INC_VERSION')) {
	return;
}

$GLOBALS[$GLOBALS['idx_lang']] = array(

	// B
	'barre_a_accent_grave' => 'Insérer un À',
	'barre_adresse' => 'Adresse',
	'barre_aide' => 'Utilisez les raccourcis typographiques pour enrichir votre mise en page',
	'barre_alignerdroite' => '[/Aligne à droite/] le paragraphe',
	'barre_ancres' => 'Gestion des ancres',
	'barre_barre' => 'Barrer le texte',
	'barre_bulle' => 'Bulle d’aide',
	'barre_c_cedille_maj' => 'Insérer un Ç',
	'barre_cadre' => 'Placer dans une &lt;cadre&gt;zone de saisie de texte&lt;/cadre&gt;',
	'barre_caracteres' => 'Caractères spéciaux',
	'barre_centrer' => '[|Centrer|] le paragraphe',
	'barre_chercher' => 'Chercher Remplacer',
	'barre_clean' => 'Nettoyer le code de toutes les balises HTML',
	'barre_code' => 'Mettre en forme un &lt;code&gt;code informatique&lt;/code&gt;',
	'barre_desindenter' => 'Désindenter une liste',
	'barre_e_accent_aigu' => 'Insérer un É',
	'barre_e_accent_grave' => 'Insérer un È',
	'barre_ea' => 'Insérer un æ',
	'barre_ea_maj' => 'Insérer un Æ',
	'barre_encadrer' => '[(Encadrer)] le paragraphe',
	'barre_eo' => 'Insérer un œ',
	'barre_eo_maj' => 'Insérer un Œ',
	'barre_euro' => 'Insérer le symbole €',
	'barre_exposant' => 'Mettre le texte en &lt;sup&gt;exposant&lt;/sup&gt;',
	'barre_formatages_speciaux' => 'Formatages spéciaux',
	'barre_galerie' => 'Ouvrir la galerie',
	'barre_gestion_anc_bulle' => 'Bulle d’aide ancre',
	'barre_gestion_anc_caption' => 'Gestion des ancres',
	'barre_gestion_anc_cible' => 'Ancre cible',
	'barre_gestion_anc_inserer' => 'Transformer en ancre',
	'barre_gestion_anc_nom' => 'Nom de l’ancre',
	'barre_gestion_anc_pointer' => 'Pointer vers une ancre',
	'barre_gestion_caption' => 'Légende et Résumé',
	'barre_gestion_colonne' => 'Nb colonnes',
	'barre_gestion_cr_casse' => 'Respecter la casse',
	'barre_gestion_cr_changercasse' => 'Changer la casse',
	'barre_gestion_cr_changercassemajuscules' => 'Passer en majuscules',
	'barre_gestion_cr_changercasseminuscules' => 'Passer en minuscules',
	'barre_gestion_cr_chercher' => 'Chercher',
	'barre_gestion_cr_entier' => 'Mot entier',
	'barre_gestion_cr_remplacer' => 'Remplacer',
	'barre_gestion_cr_tout' => 'Tout remplacer',
	'barre_gestion_entete' => 'En-tête',
	'barre_gestion_ligne' => 'Nb lignes',
	'barre_gestion_taille' => 'Taille fixe',
	'barre_glossaire' => 'Entrée du [?glossaire] (Wikipedia)',
	'barre_gras' => 'Mettre en {{gras}}',
	'barre_guillemets' => 'Entourer de « guillemets »',
	'barre_guillemets_simples' => 'Entourer de “guillemets de second niveau”',
	'barre_indenter' => 'Indenter une liste',
	'barre_inserer_cadre' => 'Insérer un code préformaté (cadre)',
	'barre_inserer_caracteres' => 'Insérer des caractères spécifiques',
	'barre_inserer_code' => 'Insérer un code informatique (code)',
	'barre_intertitre' => 'Transformer en {{{intertitre}}}',
	'barre_italic' => 'Mettre en {italique}',
	'barre_langue' => 'Langue abrégée',
	'barre_lien' => 'Transformer en [lien hypertexte->http://...]',
	'barre_lien_externe' => 'Lien externe',
	'barre_lien_input' => 'Veuillez indiquer l’adresse de votre lien (vous pouvez indiquer une adresse Internet sous la forme http://www.monsite.com, une adresse courriel, ou simplement indiquer le numéro d’un article de ce site.',
	'barre_liste_ol' => 'Mettre en liste numérotée',
	'barre_liste_ul' => 'Mettre en liste',
	'barre_lorem_ipsum' => 'Insérer un paragraphe factice',
	'barre_lorem_ipsum_3' => 'Insérer trois paragraphes factices',
	'barre_miseenevidence' => 'Mettre le texte en [*évidence*]',
	'barre_note' => 'Transformer en [[Note de bas de page]]',
	'barre_paragraphe' => 'Créer un paragraphe',
	'barre_petitescapitales' => 'Mettre le texte en &lt;sc&gt;petites capitales&lt;/sc&gt;',
	'barre_poesie' => 'Mettre en forme comme une &lt;poesie&gt;poésie&lt;/poesie&gt;',
	'barre_preview' => 'Mode prévisualisation',
	'barre_quote' => '<quote>Citer un message</quote>',
	'barre_stats' => 'Afficher les statistiques du texte',
	'barre_tableau' => 'Insérer/modifier (le sélectionner avant) un tableau',

	// C
	'config_info_enregistree' => 'Configuration sauvegardée',

	// E
	'editer' => 'Éditer',
	'explication_barre_outils_public' => 'Les scripts CSS et Javascript des barre d’outils
	(extension Porte Plume) sont chargés sur l’espace public
	et permettent d’utiliser ces barres sur les formulaires de forums,
	les crayons publics ou pour d’autres plugins, si leurs configurations
	respectives le permettent.',
	'explication_barre_outils_public_2' => 'Vous pouvez choisir de ne pas charger
	ces scripts afin d’alléger le poids des pages publiques.
	Dès lors quelle que soit la configuration des forums, crayons ou plugin,
	aucune barre d’outils du Porte Plume ne pourra être
	présente automatiquement sur l’espace public.',

	// I
	'info_barre_outils_public' => 'Barre d’outils publique',
	'info_porte_plume_titre' => 'Configurer les barres d’outils',

	// L
	'label_barre_outils_public_non' => 'Ne pas charger les scripts de barre d’outils sur l’espace public',
	'label_barre_outils_public_oui' => 'Charger les scripts de barre d’outils sur l’espace public',

	// V
	'voir' => 'Voir'
);

==> spip_4.2.9+dfsg.orig.tar.xz: plugins-dist/porte_plume/lang/barreoutils_fr_fem.php <==
<?php
// This is a SPIP language file  --  Ceci est un fichier langue de SPIP
// extrait automatiquement de https://trad.spip.net/tradlang_module/barreoutils?lang_cible=fr_fem
// ** ne pas modifier le fichier **

if (!defined('_ECRIRE_INC_VERSION')) {
	return;
}

$GLOBALS[$GLOBALS['idx_lang']] = array(

	// B
	'barre_a_accent_grave' => 'Insérer un À',
	'barre_adresse' => 'Adresse',
	'barre_aide' => 'Utilisez les raccourcis typographiques pour enrichir votre mise en page',
	'barre_alignerdroite' => '[/Aligne à droite/] le paragraphe',
	'barre_ancres' => 'Gestion des ancres',
	'barre_barre' => 'Barrer le texte',
	'barre_bulle' => 'Bulle d’aide',
	'barre_c_cedille_maj' => 'Insérer un Ç',
	'barre_cadre' => 'Placer dans une &lt;cadre&gt;zone de saisie de texte&lt;/cadre&gt;',
	'barre_caracteres' => 'Caractères spéciaux',
	'barre_centrer' => '[|Centrer|] le paragraphe',
	'barre_chercher' => 'Chercher Remplacer',
	'barre_clean' => 'Nettoyer le code de toutes les balises HTML',
	'barre_code' => 'Mettre en forme un &lt;code&gt;code informatique&lt;/code&gt;',
	'barre_desindenter' => 'Désindenter une liste',
	'barre_e_accent_aigu' => 'Insérer un É',
	'barre_e_accent_grave' => 'Insérer un È',
	'barre_ea' => 'Insérer un æ',
	'barre_ea_maj' => 'Insérer un Æ',
	'barre_encadrer' => '[(Encadrer)] le paragraphe',
	'barre_eo' => 'Insérer un œ',
	'barre_eo_maj' => 'Insérer un Œ',
	'barre_euro' => 'Insérer le symbole €',
	'barre_exposant' => 'Mettre le texte en &lt;sup&gt;exposant&lt;/sup&gt;',
	'barre_formatages_speciaux' => 'Formatages spéciaux',
	'barre_galerie' => 'Ouvrir la galerie',
	'barre_gestion_anc_bulle' => 'Bulle d’aide ancre',
	'barre_gestion_anc_caption' => 'Gestion des ancres',
	'barre_gestion_anc_cible' => 'Ancre cible',
	'barre_gestion_anc_inserer' => 'Transformer en ancre',
	'barre_gestion_anc_nom' => 'Nom de l’ancre',
	'barre_gestion_anc_pointer' => 'Pointer vers une ancre',
	'barre_gestion_caption' => 'Légende et Résumé',
	'barre_gestion_colonne' => 'Nb colonnes',
	'barre_gestion_cr_casse' => 'Respecter la casse',
	'barre_gestion_cr_changercasse' => 'Changer la casse',
	'barre_gestion_cr_changercassemajuscules' => 'Passer en majuscules',
	'barre_gestion_cr_changercasseminuscules' => 'Passer en minuscules',
	'barre_gestion_cr_chercher' => 'Chercher',
	'barre_gestion_cr_entier' => 'Mot entier',
	'barre_gestion_cr_remplacer' => 'Remplacer',
	'barre_gestion_cr_tout' => 'Tout remplacer',
	'barre_gestion_entete' => 'En-tête',
	'barre_gestion_ligne' => 'Nb lignes',
	'barre_gestion_taille' => 'Taille fixe',
	'barre_glossaire' => 'Entrée du [?glossaire] (Wikipedia)',
	'barre_gras' => 'Mettre en {{gras}}',
	'barre_guillemets' => 'Entourer de « guillemets »',
	'barre_guillemets_simples' => 'Entourer de “guillemets de second niveau”',
	'barre_indenter' => 'Indenter une liste',
	'barre_inserer_cadre' => 'Insérer un code préformaté (cadre)', # MODIF
	'barre_inserer_caracteres' => 'Insérer des caractères spécifiques',
	'barre_inserer_code' => 'Insérer un code informatique (code)', # MODIF
	'barre_intertitre' => 'Transformer en {{{intertitre}}}',
	'barre_italic' => 'Mettre en {italique}',
	'barre_langue' => 'Langue abrégée',
	'barre_lien' => 'Transformer en [lien hypertexte->http://...]',
	'barre_lien_externe' => 'Lien externe',
	'barre_lien_input' => 'Veuillez indiquer l’adresse de votre lien (vous pouvez indiquer une adresse Internet sous la forme http://www.monsite.com, une adresse courriel, ou simplement indiquer le numéro d’un article de ce site.',
	'barre_liste_ol' => 'Mettre en liste numérotée',
	'barre_liste_ul' => 'Mettre en liste',
	'barre_lorem_ipsum' => 'Insérer un paragraphe factice',
	'barre_lorem_ipsum_3' => 'Insérer trois paragraphes factices',
	'barre_miseenevidence' => 'Mettre le texte en [*évidence*]',
	'barre_note' => 'Transformer en [[Note de bas de page]]',
	'barre_paragraphe' => 'Créer un paragraphe',
	'barre_petitescapitales' => 'Mettre le texte en &lt;sc&gt;petites capitales&lt;/sc&gt;',
	'barre_poesie' => 'Mettre en forme comme une &lt;poesie&gt;poésie&lt;/poesie&gt;',
	'barre_preview' => 'Mode prévisualisation',
	'barre_quote' => '<quote>Citer un message</quote>',
	'barre_stats' => 'Afficher les statistiques du texte',
	'barre_tableau' => 'Insérer/modifier (le sélectionner avant) un tableau',

	// C
	'config_info_enregistree' => 'Configuration sauvegardée',

	// E
	'editer' => 'Éditer',
	'explication_barre_outils_public' => 'Les scripts CSS et Javascript des barre d’outils
	(extension Porte Plume) sont chargés sur l’espace public
	et permettent d’utiliser ces barres sur les formulaires de forums,
	les crayons publics ou pour d’autres plugins, si leurs configurations
	respectives le permettent.',
	'explication_barre_outils_public_2' => 'Vous pouvez choisir de ne pas charger
	ces scripts afin d’alléger le poids des pages publiques.
	Dès lors quelle que soit la configuration des forums, crayons ou plugin,
	aucune barre d’outils du Porte Plume ne pourra être
	présente automatiquement sur l’espace public.',

	// I
	'info_barre_outils_public' => 'Barre d’outils publique',
	'info_porte_plume_titre' => 'Configurer les barres d’outils',

	// L
	'label_barre_outils_public_non' => 'Ne pas charger les scripts de barre d’outils sur l’espace public',
	'label_barre_outils_public_oui' => 'Charger les scripts de barre d’outils sur l’espace public',

	// V
	'voir' => 'Voir'
);
